==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_entities/equipmentconfiguration_001/RevisionDetails.java <==

package net.datastream.schemas.mp_entities.equipmentconfiguration_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.USERID_Type;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}APPROVEDBY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}APPROVEDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}REQUESTBY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DATEREQUESTED" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}REVISIONREASON" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "approvedby",
    "approvedate",
    "requestby",
    "daterequested",
    "revisionreason"
})
@XmlRootElement(name = "RevisionDetails")
public class RevisionDetails {

    @XmlElement(name = "APPROVEDBY", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERID_Type approvedby;
    @XmlElement(name = "APPROVEDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME approvedate;
    @XmlElement(name = "REQUESTBY", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERID_Type requestby;
    @XmlElement(name = "DATEREQUESTED", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME daterequested;
    @XmlElement(name = "REVISIONREASON", namespace = "http://schemas.datastream.net/MP_fields")
    protected String revisionreason;

    /**
     * Gets the value of the approvedby property.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getAPPROVEDBY() {
        return approvedby;
    }

    /**
     * Sets the value of the approvedby property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setAPPROVEDBY(USERID_Type value) {
        this.approvedby = value;
    }

    /**
     * Gets the value of the approvedate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getAPPROVEDATE() {
        return approvedate;
    }

    /**
     * Sets the value of the approvedate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setAPPROVEDATE(DATETIME value) {
        this.approvedate = value;
    }

    /**
     * Gets the value of the requestby property.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getREQUESTBY() {
        return requestby;
    }

    /**
     * Sets the value of the requestby property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setREQUESTBY(USERID_Type value) {
        this.requestby = value;
    }

    /**
     * Gets the value of the daterequested property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getDATEREQUESTED() {
        return daterequested;
    }

    /**
     * Sets the value of the daterequested property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setDATEREQUESTED(DATETIME value) {
        this.daterequested = value;
    }

    /**
     * Gets the value of the revisionreason property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getREVISIONREASON() {
        return revisionreason;
    }

    /**
     * Sets the value of the revisionreason property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setREVISIONREASON(String value) {
        this.revisionreason = value;
    }

}

==> eam-wshub-proxyclient-12.1.0-21-sources.jar: net/datastream/schemas/mp_entities/equipmentconfiguration_001/RevisionDetails.java <==

package net.datastream.schemas.mp_entities.equipmentconfiguration_001;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.USERID_Type;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}APPROVEDBY" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}APPROVEDATE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}REQUESTBY" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}DATEREQUESTED" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}REVISIONREASON" minOccurs="0"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "approvedby",
    "approvedate",
    "requestby",
    "daterequested",
    "revisionreason"
})
@XmlRootElement(name = "RevisionDetails")
public class RevisionDetails {

    @XmlElement(name = "APPROVEDBY", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERID_Type approvedby;
    @XmlElement(name = "APPROVEDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME approvedate;
    @XmlElement(name = "REQUESTBY", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERID_Type requestby;
    @XmlElement(name = "DATEREQUESTED", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME daterequested;
    @XmlElement(name = "REVISIONREASON", namespace = "http://schemas.datastream.net/MP_fields")
    protected String revisionreason;

    /**
     * Gets the value of the approvedby property.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getAPPROVEDBY() {
        return approvedby;
    }

    /**
     * Sets the value of the approvedby property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setAPPROVEDBY(USERID_Type value) {
        this.approvedby = value;
    }

    /**
     * Gets the value of the approvedate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getAPPROVEDATE() {
        return approvedate;
    }

    /**
     * Sets the value of the approvedate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setAPPROVEDATE(DATETIME value) {
        this.approvedate = value;
    }

    /**
     * Gets the value of the requestby property.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getREQUESTBY() {
        return requestby;
    }

    /**
     * Sets the value of the requestby property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setREQUESTBY(USERID_Type value) {
        this.requestby = value;
    }

    /**
     * Gets the value of the daterequested property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getDATEREQUESTED() {
        return daterequested;
    }

    /**
     * Sets the value of the daterequested property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setDATEREQUESTED(DATETIME value) {
        this.daterequested = value;
    }

    /**
     * Gets the value of the revisionreason property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getREVISIONREASON() {
        return revisionreason;
    }

    /**
     * Sets the value of the revisionreason property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setREVISIONREASON(String value) {
        this.revisionreason = value;
    }

}
